# API Documentation of Bash Base Library

## Error Messages

### error-codes

```
error-codes (bash-yaml)
# <50 .. reserved for base-base error-codes
#  51 .. illegal handle name
#  52 .. handle unknown
#  53 .. parent path not found
#  54 .. value name not found
#  9x .. errors local to each function
```

### byml_error_string

```
byml_error_string <ret-vn> <error-code>
# returns string representation of error code
# errors: 2, 3
```

## Helper Functions

### byml_mapfun_escape_dots

```
byml_mapfun_escape_dots <dst-vn> <input-value>
# escapes all dots in input with backslashes
# errors: 2
```

## Handle handling

### byml_handle_is_open

```
byml_handle_is_open <handle>
# check if handle is open
# errors: 2, 4, 5
```

### byml_handle_open

```
byml_handle_open <handle> <path>
# note: the current implementation does not read the file, it stores
#       only its name to be passed to shyaml later on
# errors: 2, 4, 8, 9
```

### yml_handle_close

```
yml_handle_close <handle>
# errors: 2, 51, 52
```

## Getting Values

### byml_get_value

```
byml_get_value <ret-vn> <handle> <parents-vn> <name>
# get a value from a well specified path
# errors: 1, 3, 5, 6, 7, 8, 9
```

### byml_get_value_with_default

```
byml_get_value_with_default <ret-vn> <yaml-handle> <parents> <name> 
#                              <default-value>
# get a value from a well specified path
# takes default if value found but parent tree exists
# errors: 1, 3, 5, 6, 7, 8, 9
```

### byml_get_value_with_parents

```
byml_get_value_with_parents <ret-vn> <yaml-handle> <parents> <name>
# get a value from a path with fallbackup to parents
# where parent tree elements are seperated by '.'
```

### byml_get_value_with_parents_and_default

```
byml_get_value_with_parents_and_default 
#   <ret-vn> <yaml-handle> <parents> <name> <default-value>
# get a value from a well specified path, take default if not found
# errors: 1, 2, 6, 7, 8, 9
```

## Lists and Dictionaries

### byml_get_dict_keys

```
byml_get_dict_keys <ret-vn> <yaml-handle> <parents>
# returns all keys of a dictionary as bash array
# errors: 2, 3, 10, 12, 52, 53
```

### byml_get_dict_values

```
byml_get_dict_values <ret-vn> <yaml-handle> <parents>
# returns all values of a dictionary as bash array
# errors: 2, 3, 10, 12, 52, 53
```

### byml_get_list

```
byml_get_list <ret-vn> <yaml-handle> <parents>
# returns all values of a list as bash array
# errors: 2, 3, 10, 12, 52, 53
```
